# -*- coding: utf-8 -*-
"""
Created on Sat Jul 21 00:21:01 2018

@author: ASIS
"""

# outer __init__.py
from . add import add
from . divide import division
from . multiply import multiply
from . subtract import subtract
from .adv.sqrt import squareroot


# -*- coding: utf-8 -*-
"""
Created on Sat Jul 21 00:09:05 2018

@author: ASIS
"""
#%%
def add(x, y):
    return x + y

def division(x, y):
    return x / y

def multiply(x, y):
    return x * y

def subtract(x, y):
    return x - y

if __name__ == "__main__":
    import sys
    print(sys.argv)
    v = sys.argv[1].lower()
    valOne = int(sys.argv[2])
    valTwo = int(sys.argv[3])
    if v == "a":
        print(add(valOne, valTwo))
    elif v == "d":
        print(division(valOne, valTwo))
    elif v == "m":
        print(multiply(valOne, valTwo))
    elif v == "s":
        print(subtract(valOne, valTwo))
    else:
        pass
#%%


# -*- coding: utf-8 -*-
"""
Created on Sat Jul 21 23:15:59 2018

@author: ASIS
"""

from distutils.core import setup

setup(name='mymath_arun_v1',
      version='0.1',
      description='A silly math package',
      author='Mike Driscoll',
      author_email='mike@mymath.org',
      url='http://www.mymath.org/',
      packages=['mymath_arun_v1', 'mymath_arun_v1.adv'],
     )